@@ -34,14 +34,6 @@
 #endif
 
 #ifdef NEXTSTEP3
-#define SA_RESTART 0 /* not supported */
-#define O_RSYNC 0    /* not supported */
-/* prototypes in libc.h */
-extern int ftruncate(int, off_t);
-extern int fchmod(int, int);
-extern int select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
-/* in ansi string.h but undefined in -posix */
-# define bzero(b,len) memset(b,0,len)
 #define SIZEOF_IS_LONG_INT
 #define HAVE_GETRUSAGE
 #define PATH_TMP        "/private/tmp"
