@@ -17,6 +17,14 @@
 #include "config.h"
 #include "prngd.h"
 
+#ifdef NEXTSTEP3
+/* not supported */
+#define O_RSYNC 0
+
+/* ftruncate/fchmod */
+#include <libc.h>
+#endif
+
 int randsavefd;
 int debug = 0;
 
