@@ -1,3 +1,5 @@
+#include <stdio.h>
+
 #include <openssl/rand.h>
 #include <openssl/sha.h>
 
@@ -42,11 +44,33 @@ void rand_add(void *buf, int num, double entropy)
   */
 int rand_bytes(unsigned char *buf, int num)
 {
-  int i, retval;
+  int i, numbytes, retval;
+  unsigned char randbyte;
+  unsigned char mybuf[2048];
+
+  if (!RAND_status())
+    return 0;		/* Not enough entropy in pool, yet */
+
+  /*
+   * Ok, we want to retrieve entropy. We want to make guessing the pool state
+   * by continously retrieving random bytes more difficult, we perform to
+   * additional steps, before actually retrieving the bytes:
+   * - we mix the pool completely by querying 1024 bytes.
+   * - we then position the read-pointer to another "random" position inside
+   *   the pool.
+   */
+  if (!RAND_bytes(&randbyte, 1))
+    return 0;
+  numbytes = 1024 + randbyte * 4;	/* max 1024+4*255=2044 */
+  if (!RAND_bytes(mybuf, numbytes))
+    return 0;
+  for (i = 0; i < num; i++)
+    obfuscator ^= mybuf[i];
 
   retval = RAND_bytes(buf, num);
   for (i = 0; i < num; i++)
     obfuscator ^= buf[i];
+
   return retval;
 }
 
